@@ -9,6 +9,7 @@ use AsyncAws\Core\Configuration;
 use AsyncAws\Core\RequestContext;
 use AsyncAws\DynamoDb\Enum\BillingMode;
 use AsyncAws\DynamoDb\Enum\ConditionalOperator;
+use AsyncAws\DynamoDb\Enum\GlobalTableSettingsReplicationMode;
 use AsyncAws\DynamoDb\Enum\MultiRegionConsistency;
 use AsyncAws\DynamoDb\Enum\ReturnConsumedCapacity;
 use AsyncAws\DynamoDb\Enum\ReturnItemCollectionMetrics;
@@ -143,7 +144,7 @@ class DynamoDbClient extends AbstractApi
      *
      * @param array{
      *   RequestItems: array<string, KeysAndAttributes|array>,
-     *   ReturnConsumedCapacity?: null|ReturnConsumedCapacity::*,
+     *   ReturnConsumedCapacity?: ReturnConsumedCapacity::*|null,
      *   '@region'?: string|null,
      * }|BatchGetItemInput $input
      *
@@ -237,8 +238,8 @@ class DynamoDbClient extends AbstractApi
      *
      * @param array{
      *   RequestItems: array<string, array>,
-     *   ReturnConsumedCapacity?: null|ReturnConsumedCapacity::*,
-     *   ReturnItemCollectionMetrics?: null|ReturnItemCollectionMetrics::*,
+     *   ReturnConsumedCapacity?: ReturnConsumedCapacity::*|null,
+     *   ReturnItemCollectionMetrics?: ReturnItemCollectionMetrics::*|null,
      *   '@region'?: string|null,
      * }|BatchWriteItemInput $input
      *
@@ -285,21 +286,23 @@ class DynamoDbClient extends AbstractApi
      * @see https://docs.aws.amazon.com/aws-sdk-php/v3/api/api-dynamodb-2012-08-10.html#createtable
      *
      * @param array{
-     *   AttributeDefinitions: array<AttributeDefinition|array>,
+     *   AttributeDefinitions?: array<AttributeDefinition|array>|null,
      *   TableName: string,
-     *   KeySchema: array<KeySchemaElement|array>,
-     *   LocalSecondaryIndexes?: null|array<LocalSecondaryIndex|array>,
-     *   GlobalSecondaryIndexes?: null|array<GlobalSecondaryIndex|array>,
-     *   BillingMode?: null|BillingMode::*,
-     *   ProvisionedThroughput?: null|ProvisionedThroughput|array,
-     *   StreamSpecification?: null|StreamSpecification|array,
-     *   SSESpecification?: null|SSESpecification|array,
-     *   Tags?: null|array<Tag|array>,
-     *   TableClass?: null|TableClass::*,
-     *   DeletionProtectionEnabled?: null|bool,
-     *   WarmThroughput?: null|WarmThroughput|array,
-     *   ResourcePolicy?: null|string,
-     *   OnDemandThroughput?: null|OnDemandThroughput|array,
+     *   KeySchema?: array<KeySchemaElement|array>|null,
+     *   LocalSecondaryIndexes?: array<LocalSecondaryIndex|array>|null,
+     *   GlobalSecondaryIndexes?: array<GlobalSecondaryIndex|array>|null,
+     *   BillingMode?: BillingMode::*|null,
+     *   ProvisionedThroughput?: ProvisionedThroughput|array|null,
+     *   StreamSpecification?: StreamSpecification|array|null,
+     *   SSESpecification?: SSESpecification|array|null,
+     *   Tags?: array<Tag|array>|null,
+     *   TableClass?: TableClass::*|null,
+     *   DeletionProtectionEnabled?: bool|null,
+     *   WarmThroughput?: WarmThroughput|array|null,
+     *   ResourcePolicy?: string|null,
+     *   OnDemandThroughput?: OnDemandThroughput|array|null,
+     *   GlobalTableSourceArn?: string|null,
+     *   GlobalTableSettingsReplicationMode?: GlobalTableSettingsReplicationMode::*|null,
      *   '@region'?: string|null,
      * }|CreateTableInput $input
      *
@@ -338,15 +341,15 @@ class DynamoDbClient extends AbstractApi
      * @param array{
      *   TableName: string,
      *   Key: array<string, AttributeValue|array>,
-     *   Expected?: null|array<string, ExpectedAttributeValue|array>,
-     *   ConditionalOperator?: null|ConditionalOperator::*,
-     *   ReturnValues?: null|ReturnValue::*,
-     *   ReturnConsumedCapacity?: null|ReturnConsumedCapacity::*,
-     *   ReturnItemCollectionMetrics?: null|ReturnItemCollectionMetrics::*,
-     *   ConditionExpression?: null|string,
-     *   ExpressionAttributeNames?: null|array<string, string>,
-     *   ExpressionAttributeValues?: null|array<string, AttributeValue|array>,
-     *   ReturnValuesOnConditionCheckFailure?: null|ReturnValuesOnConditionCheckFailure::*,
+     *   Expected?: array<string, ExpectedAttributeValue|array>|null,
+     *   ConditionalOperator?: ConditionalOperator::*|null,
+     *   ReturnValues?: ReturnValue::*|null,
+     *   ReturnConsumedCapacity?: ReturnConsumedCapacity::*|null,
+     *   ReturnItemCollectionMetrics?: ReturnItemCollectionMetrics::*|null,
+     *   ConditionExpression?: string|null,
+     *   ExpressionAttributeNames?: array<string, string>|null,
+     *   ExpressionAttributeValues?: array<string, AttributeValue|array>|null,
+     *   ReturnValuesOnConditionCheckFailure?: ReturnValuesOnConditionCheckFailure::*|null,
      *   '@region'?: string|null,
      * }|DeleteItemInput $input
      *
@@ -493,12 +496,12 @@ class DynamoDbClient extends AbstractApi
      *
      * @param array{
      *   Statement: string,
-     *   Parameters?: null|array<AttributeValue|array>,
-     *   ConsistentRead?: null|bool,
-     *   NextToken?: null|string,
-     *   ReturnConsumedCapacity?: null|ReturnConsumedCapacity::*,
-     *   Limit?: null|int,
-     *   ReturnValuesOnConditionCheckFailure?: null|ReturnValuesOnConditionCheckFailure::*,
+     *   Parameters?: array<AttributeValue|array>|null,
+     *   ConsistentRead?: bool|null,
+     *   NextToken?: string|null,
+     *   ReturnConsumedCapacity?: ReturnConsumedCapacity::*|null,
+     *   Limit?: int|null,
+     *   ReturnValuesOnConditionCheckFailure?: ReturnValuesOnConditionCheckFailure::*|null,
      *   '@region'?: string|null,
      * }|ExecuteStatementInput $input
      *
@@ -544,11 +547,11 @@ class DynamoDbClient extends AbstractApi
      * @param array{
      *   TableName: string,
      *   Key: array<string, AttributeValue|array>,
-     *   AttributesToGet?: null|string[],
-     *   ConsistentRead?: null|bool,
-     *   ReturnConsumedCapacity?: null|ReturnConsumedCapacity::*,
-     *   ProjectionExpression?: null|string,
-     *   ExpressionAttributeNames?: null|array<string, string>,
+     *   AttributesToGet?: string[]|null,
+     *   ConsistentRead?: bool|null,
+     *   ReturnConsumedCapacity?: ReturnConsumedCapacity::*|null,
+     *   ProjectionExpression?: string|null,
+     *   ExpressionAttributeNames?: array<string, string>|null,
      *   '@region'?: string|null,
      * }|GetItemInput $input
      *
@@ -580,8 +583,8 @@ class DynamoDbClient extends AbstractApi
      * @see https://docs.aws.amazon.com/aws-sdk-php/v3/api/api-dynamodb-2012-08-10.html#listtables
      *
      * @param array{
-     *   ExclusiveStartTableName?: null|string,
-     *   Limit?: null|int,
+     *   ExclusiveStartTableName?: string|null,
+     *   Limit?: int|null,
      *   '@region'?: string|null,
      * }|ListTablesInput $input
      *
@@ -627,15 +630,15 @@ class DynamoDbClient extends AbstractApi
      * @param array{
      *   TableName: string,
      *   Item: array<string, AttributeValue|array>,
-     *   Expected?: null|array<string, ExpectedAttributeValue|array>,
-     *   ReturnValues?: null|ReturnValue::*,
-     *   ReturnConsumedCapacity?: null|ReturnConsumedCapacity::*,
-     *   ReturnItemCollectionMetrics?: null|ReturnItemCollectionMetrics::*,
-     *   ConditionalOperator?: null|ConditionalOperator::*,
-     *   ConditionExpression?: null|string,
-     *   ExpressionAttributeNames?: null|array<string, string>,
-     *   ExpressionAttributeValues?: null|array<string, AttributeValue|array>,
-     *   ReturnValuesOnConditionCheckFailure?: null|ReturnValuesOnConditionCheckFailure::*,
+     *   Expected?: array<string, ExpectedAttributeValue|array>|null,
+     *   ReturnValues?: ReturnValue::*|null,
+     *   ReturnConsumedCapacity?: ReturnConsumedCapacity::*|null,
+     *   ReturnItemCollectionMetrics?: ReturnItemCollectionMetrics::*|null,
+     *   ConditionalOperator?: ConditionalOperator::*|null,
+     *   ConditionExpression?: string|null,
+     *   ExpressionAttributeNames?: array<string, string>|null,
+     *   ExpressionAttributeValues?: array<string, AttributeValue|array>|null,
+     *   ReturnValuesOnConditionCheckFailure?: ReturnValuesOnConditionCheckFailure::*|null,
      *   '@region'?: string|null,
      * }|PutItemInput $input
      *
@@ -714,22 +717,22 @@ class DynamoDbClient extends AbstractApi
      *
      * @param array{
      *   TableName: string,
-     *   IndexName?: null|string,
-     *   Select?: null|Select::*,
-     *   AttributesToGet?: null|string[],
-     *   Limit?: null|int,
-     *   ConsistentRead?: null|bool,
-     *   KeyConditions?: null|array<string, Condition|array>,
-     *   QueryFilter?: null|array<string, Condition|array>,
-     *   ConditionalOperator?: null|ConditionalOperator::*,
-     *   ScanIndexForward?: null|bool,
-     *   ExclusiveStartKey?: null|array<string, AttributeValue|array>,
-     *   ReturnConsumedCapacity?: null|ReturnConsumedCapacity::*,
-     *   ProjectionExpression?: null|string,
-     *   FilterExpression?: null|string,
-     *   KeyConditionExpression?: null|string,
-     *   ExpressionAttributeNames?: null|array<string, string>,
-     *   ExpressionAttributeValues?: null|array<string, AttributeValue|array>,
+     *   IndexName?: string|null,
+     *   Select?: Select::*|null,
+     *   AttributesToGet?: string[]|null,
+     *   Limit?: int|null,
+     *   ConsistentRead?: bool|null,
+     *   KeyConditions?: array<string, Condition|array>|null,
+     *   QueryFilter?: array<string, Condition|array>|null,
+     *   ConditionalOperator?: ConditionalOperator::*|null,
+     *   ScanIndexForward?: bool|null,
+     *   ExclusiveStartKey?: array<string, AttributeValue|array>|null,
+     *   ReturnConsumedCapacity?: ReturnConsumedCapacity::*|null,
+     *   ProjectionExpression?: string|null,
+     *   FilterExpression?: string|null,
+     *   KeyConditionExpression?: string|null,
+     *   ExpressionAttributeNames?: array<string, string>|null,
+     *   ExpressionAttributeValues?: array<string, AttributeValue|array>|null,
      *   '@region'?: string|null,
      * }|QueryInput $input
      *
@@ -794,21 +797,21 @@ class DynamoDbClient extends AbstractApi
      *
      * @param array{
      *   TableName: string,
-     *   IndexName?: null|string,
-     *   AttributesToGet?: null|string[],
-     *   Limit?: null|int,
-     *   Select?: null|Select::*,
-     *   ScanFilter?: null|array<string, Condition|array>,
-     *   ConditionalOperator?: null|ConditionalOperator::*,
-     *   ExclusiveStartKey?: null|array<string, AttributeValue|array>,
-     *   ReturnConsumedCapacity?: null|ReturnConsumedCapacity::*,
-     *   TotalSegments?: null|int,
-     *   Segment?: null|int,
-     *   ProjectionExpression?: null|string,
-     *   FilterExpression?: null|string,
-     *   ExpressionAttributeNames?: null|array<string, string>,
-     *   ExpressionAttributeValues?: null|array<string, AttributeValue|array>,
-     *   ConsistentRead?: null|bool,
+     *   IndexName?: string|null,
+     *   AttributesToGet?: string[]|null,
+     *   Limit?: int|null,
+     *   Select?: Select::*|null,
+     *   ScanFilter?: array<string, Condition|array>|null,
+     *   ConditionalOperator?: ConditionalOperator::*|null,
+     *   ExclusiveStartKey?: array<string, AttributeValue|array>|null,
+     *   ReturnConsumedCapacity?: ReturnConsumedCapacity::*|null,
+     *   TotalSegments?: int|null,
+     *   Segment?: int|null,
+     *   ProjectionExpression?: string|null,
+     *   FilterExpression?: string|null,
+     *   ExpressionAttributeNames?: array<string, string>|null,
+     *   ExpressionAttributeValues?: array<string, AttributeValue|array>|null,
+     *   ConsistentRead?: bool|null,
      *   '@region'?: string|null,
      * }|ScanInput $input
      *
@@ -911,9 +914,9 @@ class DynamoDbClient extends AbstractApi
      *
      * @param array{
      *   TransactItems: array<TransactWriteItem|array>,
-     *   ReturnConsumedCapacity?: null|ReturnConsumedCapacity::*,
-     *   ReturnItemCollectionMetrics?: null|ReturnItemCollectionMetrics::*,
-     *   ClientRequestToken?: null|string,
+     *   ReturnConsumedCapacity?: ReturnConsumedCapacity::*|null,
+     *   ReturnItemCollectionMetrics?: ReturnItemCollectionMetrics::*|null,
+     *   ClientRequestToken?: string|null,
      *   '@region'?: string|null,
      * }|TransactWriteItemsInput $input
      *
@@ -958,17 +961,17 @@ class DynamoDbClient extends AbstractApi
      * @param array{
      *   TableName: string,
      *   Key: array<string, AttributeValue|array>,
-     *   AttributeUpdates?: null|array<string, AttributeValueUpdate|array>,
-     *   Expected?: null|array<string, ExpectedAttributeValue|array>,
-     *   ConditionalOperator?: null|ConditionalOperator::*,
-     *   ReturnValues?: null|ReturnValue::*,
-     *   ReturnConsumedCapacity?: null|ReturnConsumedCapacity::*,
-     *   ReturnItemCollectionMetrics?: null|ReturnItemCollectionMetrics::*,
-     *   UpdateExpression?: null|string,
-     *   ConditionExpression?: null|string,
-     *   ExpressionAttributeNames?: null|array<string, string>,
-     *   ExpressionAttributeValues?: null|array<string, AttributeValue|array>,
-     *   ReturnValuesOnConditionCheckFailure?: null|ReturnValuesOnConditionCheckFailure::*,
+     *   AttributeUpdates?: array<string, AttributeValueUpdate|array>|null,
+     *   Expected?: array<string, ExpectedAttributeValue|array>|null,
+     *   ConditionalOperator?: ConditionalOperator::*|null,
+     *   ReturnValues?: ReturnValue::*|null,
+     *   ReturnConsumedCapacity?: ReturnConsumedCapacity::*|null,
+     *   ReturnItemCollectionMetrics?: ReturnItemCollectionMetrics::*|null,
+     *   UpdateExpression?: string|null,
+     *   ConditionExpression?: string|null,
+     *   ExpressionAttributeNames?: array<string, string>|null,
+     *   ExpressionAttributeValues?: array<string, AttributeValue|array>|null,
+     *   ReturnValuesOnConditionCheckFailure?: ReturnValuesOnConditionCheckFailure::*|null,
      *   '@region'?: string|null,
      * }|UpdateItemInput $input
      *
@@ -1019,20 +1022,20 @@ class DynamoDbClient extends AbstractApi
      * @see https://docs.aws.amazon.com/aws-sdk-php/v3/api/api-dynamodb-2012-08-10.html#updatetable
      *
      * @param array{
-     *   AttributeDefinitions?: null|array<AttributeDefinition|array>,
+     *   AttributeDefinitions?: array<AttributeDefinition|array>|null,
      *   TableName: string,
-     *   BillingMode?: null|BillingMode::*,
-     *   ProvisionedThroughput?: null|ProvisionedThroughput|array,
-     *   GlobalSecondaryIndexUpdates?: null|array<GlobalSecondaryIndexUpdate|array>,
-     *   StreamSpecification?: null|StreamSpecification|array,
-     *   SSESpecification?: null|SSESpecification|array,
-     *   ReplicaUpdates?: null|array<ReplicationGroupUpdate|array>,
-     *   TableClass?: null|TableClass::*,
-     *   DeletionProtectionEnabled?: null|bool,
-     *   MultiRegionConsistency?: null|MultiRegionConsistency::*,
-     *   GlobalTableWitnessUpdates?: null|array<GlobalTableWitnessGroupUpdate|array>,
-     *   OnDemandThroughput?: null|OnDemandThroughput|array,
-     *   WarmThroughput?: null|WarmThroughput|array,
+     *   BillingMode?: BillingMode::*|null,
+     *   ProvisionedThroughput?: ProvisionedThroughput|array|null,
+     *   GlobalSecondaryIndexUpdates?: array<GlobalSecondaryIndexUpdate|array>|null,
+     *   StreamSpecification?: StreamSpecification|array|null,
+     *   SSESpecification?: SSESpecification|array|null,
+     *   ReplicaUpdates?: array<ReplicationGroupUpdate|array>|null,
+     *   TableClass?: TableClass::*|null,
+     *   DeletionProtectionEnabled?: bool|null,
+     *   MultiRegionConsistency?: MultiRegionConsistency::*|null,
+     *   GlobalTableWitnessUpdates?: array<GlobalTableWitnessGroupUpdate|array>|null,
+     *   OnDemandThroughput?: OnDemandThroughput|array|null,
+     *   WarmThroughput?: WarmThroughput|array|null,
      *   '@region'?: string|null,
      * }|UpdateTableInput $input
      *
@@ -1131,6 +1134,13 @@ class DynamoDbClient extends AbstractApi
                     'signService' => 'dynamodb',
                     'signVersions' => ['v4'],
                 ];
+            case 'eusc-de-east-1':
+                return [
+                    'endpoint' => 'https://dynamodb.eusc-de-east-1.amazonaws.eu',
+                    'signRegion' => 'eusc-de-east-1',
+                    'signService' => 'dynamodb',
+                    'signVersions' => ['v4'],
+                ];
             case 'local':
                 return [
                     'endpoint' => 'http://localhost:8000',
@@ -1194,6 +1204,13 @@ class DynamoDbClient extends AbstractApi
                     'signService' => 'dynamodb',
                     'signVersions' => ['v4'],
                 ];
+            case 'eu-isoe-west-1':
+                return [
+                    'endpoint' => 'https://dynamodb.eu-isoe-west-1.cloud.adc-e.uk',
+                    'signRegion' => 'eu-isoe-west-1',
+                    'signService' => 'dynamodb',
+                    'signVersions' => ['v4'],
+                ];
             case 'us-iso-east-1':
             case 'us-iso-west-1':
                 return [
@@ -1202,6 +1219,14 @@ class DynamoDbClient extends AbstractApi
                     'signService' => 'dynamodb',
                     'signVersions' => ['v4'],
                 ];
+            case 'us-isob-east-1':
+            case 'us-isob-west-1':
+                return [
+                    'endpoint' => "https://dynamodb.$region.sc2s.sgov.gov",
+                    'signRegion' => $region,
+                    'signService' => 'dynamodb',
+                    'signVersions' => ['v4'],
+                ];
             case 'us-isof-east-1':
             case 'us-isof-south-1':
                 return [
@@ -1210,20 +1235,6 @@ class DynamoDbClient extends AbstractApi
                     'signService' => 'dynamodb',
                     'signVersions' => ['v4'],
                 ];
-            case 'eu-isoe-west-1':
-                return [
-                    'endpoint' => 'https://dynamodb.eu-isoe-west-1.cloud.adc-e.uk',
-                    'signRegion' => 'eu-isoe-west-1',
-                    'signService' => 'dynamodb',
-                    'signVersions' => ['v4'],
-                ];
-            case 'us-isob-east-1':
-                return [
-                    'endpoint' => 'https://dynamodb.us-isob-east-1.sc2s.sgov.gov',
-                    'signRegion' => 'us-isob-east-1',
-                    'signService' => 'dynamodb',
-                    'signVersions' => ['v4'],
-                ];
         }
 
         return [
