@@ -7,7 +7,11 @@ final class WitnessStatus
     public const ACTIVE = 'ACTIVE';
     public const CREATING = 'CREATING';
     public const DELETING = 'DELETING';
+    public const UNKNOWN_TO_SDK = 'UNKNOWN_TO_SDK';
 
+    /**
+     * @psalm-assert-if-true self::* $value
+     */
     public static function exists(string $value): bool
     {
         return isset([
